pub struct Loki {}Expand description
A factory for creating Grafana Loki loggers using a fluent builder pattern.
This factory provides two paths for construction:
- Standard: Uses the default network-based Loki service.
- Injected: Allows providing a custom implementation of the
Lokitrait.
Implementations
Sourceimpl Loki
impl Loki
Sourcepub fn config(self, config: LokiConfig) -> LokiConfig
pub fn config(self, config: LokiConfig) -> LokiConfig
Begins the building process by providing a LokiConfig.
Sourcepub fn service(
self,
config: LokiConfig,
service: Box<dyn Loki + Send + Sync>,
) -> LokiFactoryService
pub fn service( self, config: LokiConfig, service: Box<dyn Loki + Send + Sync>, ) -> LokiFactoryService
Shortcut to create a factory state with a pre-defined configuration and service.