pub struct LokiConfig { /* private fields */ }Expand description
A middle-state builder that holds the Loki configuration.
From here, you can either build a standard logger or transition to a service-injected state.
Implementations
Sourceimpl LokiConfig
impl LokiConfig
Sourcepub fn new(config: LokiConfig) -> Self
pub fn new(config: LokiConfig) -> Self
Creates a new LokiFactoryConfig
Sourcepub fn get_config(&self) -> &LokiConfig
pub fn get_config(&self) -> &LokiConfig
Returns a reference to the internal configuration.
Sourcepub fn config(self, config: LokiConfig) -> Self
pub fn config(self, config: LokiConfig) -> Self
Sets underlying configuration.
Sourcepub fn build(self) -> Logger
pub fn build(self) -> Logger
Finalizes the builder and returns a high-level Logger.
This will initialize the default background worker and HTTP client.
Sourcepub fn build_impl(self) -> Box<LokiLogger>
pub fn build_impl(self) -> Box<LokiLogger>
Builds the underlying LokiLogger implementation without the generic wrapper.